==> plasma-workspace_5.18.8.orig.tar.xz: plasma-workspace-5.18.8/applets/kicker/plugin/systemsettings.cpp <==
/***************************************************************************
 *   Copyright (C) 2015 by Eike Hein <hein@kde.org>                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#include "systemsettings.h"

#include <QStandardPaths>

SystemSettings::SystemSettings(QObject *parent) : QObject(parent)
{
}

SystemSettings::~SystemSettings()
{
}

QString SystemSettings::picturesLocation() const
{
    QString path;

    const QStringList &locations = QStandardPaths::standardLocations(QStandardPaths::PicturesLocation);

    if (!locations.isEmpty()) {
        path = locations.at(0);
    } else {
        // HomeLocation is guaranteed not to be empty.
        path = QStandardPaths::standardLocations(QStandardPaths::HomeLocation).at(0);
    }

    return path;
}

==> plasma-workspace-5.22.2.1.tar.xz: plasma-workspace-5.22.2.1/applets/kicker/plugin/systemsettings.cpp <==
/***************************************************************************
 *   Copyright (C) 2015 by Eike Hein <hein@kde.org>                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#include "systemsettings.h"

#include <QStandardPaths>

SystemSettings::SystemSettings(QObject *parent)
    : QObject(parent)
{
}

SystemSettings::~SystemSettings()
{
}

QString SystemSettings::picturesLocation() const
{
    QString path;

    const QStringList &locations = QStandardPaths::standardLocations(QStandardPaths::PicturesLocation);

    if (!locations.isEmpty()) {
        path = locations.at(0);
    } else {
        // HomeLocation is guaranteed not to be empty.
        path = QStandardPaths::standardLocations(QStandardPaths::HomeLocation).at(0);
    }

    return path;
}
